@@ -230,6 +230,11 @@ private:
 // Hex
 // -------------------------------------------------------
 
+PdfHexFilter::PdfHexFilter()
+    : m_cDecodedByte( 0 ), m_bLow( true )
+{
+}
+
 void PdfHexFilter::EncodeBlockImpl( const char* pBuffer, pdf_long lLen )
 {
     char data[2];
@@ -301,6 +306,11 @@ void PdfHexFilter::EndDecodeImpl()
 // Paul Haahr - http://www.webcom.com/~haahr/
 // -------------------------------------------------------
 
+PdfAscii85Filter::PdfAscii85Filter()
+    : m_count( 0 ), m_tuple( 0 )
+{
+}
+
 void PdfAscii85Filter::EncodeTuple( unsigned long tuple, int count )
 {
     int      i      = 5;
@@ -606,6 +616,11 @@ void PdfFlateFilter::EndDecodeImpl()
 // RLE
 // -------------------------------------------------------
 
+PdfRLEFilter::PdfRLEFilter()
+    : m_nCodeLen( 0 )
+{
+}
+
 void PdfRLEFilter::BeginEncodeImpl()
 {
     PODOFO_RAISE_ERROR( ePdfError_UnsupportedFilter );
@@ -862,6 +877,8 @@ void JPegErrorOutput(j_common_ptr, int)
 PdfDCTFilter::PdfDCTFilter()
     : m_pDevice( NULL )
 {
+    memset( &m_cinfo, 0, sizeof( struct jpeg_decompress_struct ) );
+    memset( &m_jerr, 0, sizeof( struct jpeg_error_mgr ) );
 }
 
 PdfDCTFilter::~PdfDCTFilter()
